@@ -65,9 +65,20 @@ class CAPPublisher(object):
 
 
 if __name__ == '__main__':
-    config: CAPConfig = CAPConfig(host="rabbitmq.dev.co", port="15672", virtual_host="CityOcean-Dev",
-                                  exchange="CO-Exchange", user="co", password="co@rabbitmq.com",
-                                  storage=CAPStorageConfig(server="db.dev.com", database="CO_EventBus", user="co",
-                                                           password="Co&23@2332$22"))
+    config = {
+        "host": "rabbitmq.dev.co",
+        "port": "15672",
+        "enabled": "true",
+        "virtual_host": "CityOcean-Test",
+        "exchange": "CO-Exchange",
+        "user": "co",
+        "password": "co@rabbitmq.com",
+        "storage": {
+            "server": "db.test.com",
+            "database": "CO_EventBus",
+            "user": "co",
+            "password": "Co&23@2332$22"
+        }
+    }
     publisher = CAPPublisher(config)
     publisher.publish("spider_container_tracking_changed", ["MRKU2226829", "MSKU8479446"])
